PutFunctionInput

Struct PutFunctionInput 

#[non_exhaustive]
pub struct PutFunctionInput { pub function_id: Option<String>, pub function_type: Option<FunctionType>, pub description: Option<String>, pub http_request_configuration: Option<HttpRequestConfiguration>, pub custom_output_configuration: Option<CustomOutputConfiguration>, pub sequential_executor_configuration: Option<SequentialExecutorConfiguration>, pub tags: Option<HashMap<String, String>>, }
– Define Mixin –

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
function_id: Option<String>

The identifier of the function. The identifier must be unique within your account.

function_type: Option<FunctionType>

The type of the function. The function type determines what the function can do at runtime. Valid values: CUSTOM_OUTPUT evaluates expressions and produces output bindings with no external calls. HTTP_REQUEST makes an HTTP call to an external service and evaluates output expressions that can reference the response. SEQUENTIAL_EXECUTOR runs a sequence of child functions in order, passing data between steps through temporary data. For more information, see Function types and composition in the MediaTailor User Guide.

description: Option<String>

A description of the function.

http_request_configuration: Option<HttpRequestConfiguration>

The configuration for an HTTP_REQUEST function. Specifies the HTTP method, URL, headers, body, timeout, and output expressions. Required when FunctionType is HTTP_REQUEST.

custom_output_configuration: Option<CustomOutputConfiguration>

The configuration for a CUSTOM_OUTPUT function. Specifies the runtime and output expressions. Required when FunctionType is CUSTOM_OUTPUT.

sequential_executor_configuration: Option<SequentialExecutorConfiguration>

The configuration for a SEQUENTIAL_EXECUTOR function. Specifies the ordered list of child functions to execute, an optional output block, and a timeout. Required when FunctionType is SEQUENTIAL_EXECUTOR.

tags: Option<HashMap<String, String>>

The tags to assign to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Implementations

Source

impl PutFunctionInput

pub fn function_id(&self) -> Option<&str>

The identifier of the function. The identifier must be unique within your account.

pub fn function_type(&self) -> Option<&FunctionType>

The type of the function. The function type determines what the function can do at runtime. Valid values: CUSTOM_OUTPUT evaluates expressions and produces output bindings with no external calls. HTTP_REQUEST makes an HTTP call to an external service and evaluates output expressions that can reference the response. SEQUENTIAL_EXECUTOR runs a sequence of child functions in order, passing data between steps through temporary data. For more information, see Function types and composition in the MediaTailor User Guide.

pub fn description(&self) -> Option<&str>

A description of the function.

pub fn http_request_configuration(&self) -> Option<&HttpRequestConfiguration>

The configuration for an HTTP_REQUEST function. Specifies the HTTP method, URL, headers, body, timeout, and output expressions. Required when FunctionType is HTTP_REQUEST.

pub fn custom_output_configuration(&self) -> Option<&CustomOutputConfiguration>

The configuration for a CUSTOM_OUTPUT function. Specifies the runtime and output expressions. Required when FunctionType is CUSTOM_OUTPUT.

pub fn sequential_executor_configuration( &self, ) -> Option<&SequentialExecutorConfiguration>

The configuration for a SEQUENTIAL_EXECUTOR function. Specifies the ordered list of child functions to execute, an optional output block, and a timeout. Required when FunctionType is SEQUENTIAL_EXECUTOR.

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags to assign to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.

Source

impl PutFunctionInput

pub fn builder() -> PutFunctionInputBuilder

Creates a new builder-style object to manufacture PutFunctionInput.