#[non_exhaustive]pub struct PutFunctionOutput {
pub function_id: String,
pub function_type: FunctionType,
pub description: Option<String>,
pub http_request_configuration: Option<HttpRequestConfiguration>,
pub custom_output_configuration: Option<CustomOutputConfiguration>,
pub sequential_executor_configuration: Option<SequentialExecutorConfiguration>,
pub tags: Option<HashMap<String, String>>,
pub arn: Option<String>,
/* private fields */
}Expand description
– Define Mixin –
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.function_id: StringThe identifier of the function.
function_type: FunctionTypeThe type of the function.
description: Option<String>A description of the function.
http_request_configuration: Option<HttpRequestConfiguration>The configuration for an HTTP_REQUEST function.
custom_output_configuration: Option<CustomOutputConfiguration>The configuration for a CUSTOM_OUTPUT function.
sequential_executor_configuration: Option<SequentialExecutorConfiguration>The configuration for a SEQUENTIAL_EXECUTOR function.
The tags assigned to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
arn: Option<String>The Amazon Resource Name (ARN) of the function.
Implementations
Sourceimpl PutFunctionOutput
impl PutFunctionOutput
Sourcepub fn function_id(&self) -> &str
pub fn function_id(&self) -> &str
The identifier of the function.
Sourcepub fn function_type(&self) -> &FunctionType
pub fn function_type(&self) -> &FunctionType
The type of the function.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the function.
Sourcepub fn http_request_configuration(&self) -> Option<&HttpRequestConfiguration>
pub fn http_request_configuration(&self) -> Option<&HttpRequestConfiguration>
The configuration for an HTTP_REQUEST function.
Sourcepub fn custom_output_configuration(&self) -> Option<&CustomOutputConfiguration>
pub fn custom_output_configuration(&self) -> Option<&CustomOutputConfiguration>
The configuration for a CUSTOM_OUTPUT function.
Sourcepub fn sequential_executor_configuration(
&self,
) -> Option<&SequentialExecutorConfiguration>
pub fn sequential_executor_configuration( &self, ) -> Option<&SequentialExecutorConfiguration>
The configuration for a SEQUENTIAL_EXECUTOR function.
The tags assigned to the function. Tags are key-value pairs that you can associate with Amazon resources to help with organization, access control, and cost tracking. For more information, see Tagging AWS Elemental MediaTailor Resources.
Sourceimpl PutFunctionOutput
impl PutFunctionOutput
Sourcepub fn builder() -> PutFunctionOutputBuilder
pub fn builder() -> PutFunctionOutputBuilder
Creates a new builder-style object to manufacture PutFunctionOutput.